@@ -96,6 +96,7 @@ class App:
     @staticmethod
     def start():
         port = select_port()
+        print("select_port")
         print(port)
         write_port_to_file(port)
         try:
@@ -143,7 +144,9 @@ def select_port():
 def write_port_to_file(port):
     with open('/application/.runtime/status.json', 'r') as json_file:
         data = json.load(json_file)
-        data["python-executor"]["port"] = port
+        print("write_port_to_file")
+        print(str(port))
+        data["python-executor"]["port"] = str(port)
     with open('/application/.runtime/status.json', 'w') as output_file:
         json.dump(data, output_file)
 
